@@ -2,11 +2,14 @@
 __init__.py : Trovebox package top level
 """
 from .http import Http
-from .errors import *
+from .errors import TroveboxError, TroveboxDuplicateError, Trovebox404Error
 from ._version import __version__
-from . import api_photo
-from . import api_tag
-from . import api_album
+from trovebox.api import api_photo
+from trovebox.api import api_tag
+from trovebox.api import api_album
+from trovebox.api import api_action
+from trovebox.api import api_activity
+from trovebox.api import api_system
 
 LATEST_API_VERSION = 2
 
@@ -36,3 +39,7 @@ class Trovebox(Http):
         self.tag = api_tag.ApiTag(self)
         self.albums = api_album.ApiAlbums(self)
         self.album = api_album.ApiAlbum(self)
+        self.action = api_action.ApiAction(self)
+        self.activities = api_activity.ApiActivities(self)
+        self.activity = api_activity.ApiActivity(self)
+        self.system = api_system.ApiSystem(self)
